==> jc-1.4.0.tar.gz: javax/swing/colorchooser/ColorChooserComponentFactory.h <==
// public class javax.swing.colorchooser.ColorChooserComponentFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c44e258350a97683 javax_swing_colorchooser_ColorChooserComponentFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_ColorChooserComponentFactory_H_
#define _JC_javax_swing_colorchooser_ColorChooserComponentFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_refs	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_refs;
typedef struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_nonrefs	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$refs	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$refs;
typedef struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$nonrefs	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$nonrefs;
typedef struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$object	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$object;

typedef const struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vmethods	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vmethods;
typedef const struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtable	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtable;
typedef const struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtype	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_ColorChooserComponentFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$object *);

// Static methods
extern _jc_object_array *_jc_javax_swing_colorchooser_ColorChooserComponentFactory$method$getDefaultChooserPanels$4dfa7f22b86a56a4(_jc_env *);
extern struct _jc_javax_swing_JComponent$object *_jc_javax_swing_colorchooser_ColorChooserComponentFactory$method$getPreviewPanel$550f9a1ad0964318(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vmethods {
};

// Vtable
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vmethods	javax_swing_colorchooser_ColorChooserComponentFactory;
};

// Vtype
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$refs {
    _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_refs	javax_swing_colorchooser_ColorChooserComponentFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_nonrefs	javax_swing_colorchooser_ColorChooserComponentFactory;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$object {
	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtype	*vtype;
	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtype _jc_javax_swing_colorchooser_ColorChooserComponentFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_ColorChooserComponentFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_ColorChooserComponentFactory$class_object;

#endif	/* _JC_javax_swing_colorchooser_ColorChooserComponentFactory_H_ */

==> jc-1.4.6.tar.gz: javax/swing/colorchooser/ColorChooserComponentFactory.h <==
// public class javax.swing.colorchooser.ColorChooserComponentFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c44e258350a97683 javax_swing_colorchooser_ColorChooserComponentFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_ColorChooserComponentFactory_H_
#define _JC_javax_swing_colorchooser_ColorChooserComponentFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_refs	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_refs;
typedef struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_nonrefs	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$refs	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$refs;
typedef struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$nonrefs	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$nonrefs;
typedef struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$object	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$object;

typedef const struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vmethods	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vmethods;
typedef const struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtable	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtable;
typedef const struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtype	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_ColorChooserComponentFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$object *) _JC_JCNI_ATTR;

// Static methods
extern _jc_object_array *_jc_javax_swing_colorchooser_ColorChooserComponentFactory$method$getDefaultChooserPanels$4dfa7f22b86a56a4(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_JComponent$object *_jc_javax_swing_colorchooser_ColorChooserComponentFactory$method$getPreviewPanel$550f9a1ad0964318(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vmethods {
};

// Vtable
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vmethods	javax_swing_colorchooser_ColorChooserComponentFactory;
};

// Vtype
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$refs {
    _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_refs	javax_swing_colorchooser_ColorChooserComponentFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_ColorChooserComponentFactory$sub_nonrefs	javax_swing_colorchooser_ColorChooserComponentFactory;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_ColorChooserComponentFactory$object {
	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtype	*vtype;
	_jc_javax_swing_colorchooser_ColorChooserComponentFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_ColorChooserComponentFactory$vtype _jc_javax_swing_colorchooser_ColorChooserComponentFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_ColorChooserComponentFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_ColorChooserComponentFactory$class_object;

#endif	/* _JC_javax_swing_colorchooser_ColorChooserComponentFactory_H_ */
